@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Test::Warnings; # git description: v0.019-2-g3cde069
+package Test::Warnings; # git description: v0.021-8-g8fb33bb
 # ABSTRACT: Test for warnings and the lack of them
 # KEYWORDS: testing tests warnings
-# vim: set ts=8 sw=4 tw=78 et :
-$Test::Warnings::VERSION = '0.020';
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '0.022';
+
 use parent 'Exporter';
 use Test::Builder;
 
@@ -42,23 +44,23 @@ sub _builder(;$)
     $tb = shift;
 }
 
+my $_orig_warn_handler = $SIG{__WARN__};
 $SIG{__WARN__} = sub {
-    my $msg = shift;
-
     if ($warnings_allowed)
     {
-        Test::Builder->new->note($msg);
+        Test::Builder->new->note($_[0]);
     }
     else
     {
-        if ($msg =~ /\n$/) {
-            warn $msg;
+        $forbidden_warnings_found++;
+        goto &$_orig_warn_handler if $_orig_warn_handler;
+
+        if ($_[0] =~ /\n$/) {
+            warn $_[0];
         } else {
             require Carp;
-            Carp::carp($msg);
+            Carp::carp($_[0]);
         }
-
-        $forbidden_warnings_found++;
     }
 };
 
@@ -146,7 +148,7 @@ Test::Warnings - Test for warnings and the lack of them
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -268,6 +270,14 @@ since they are returned from this function with their filename and line
 numbers intact, you can re-issue them yourself immediately after calling
 C<warnings(...)>, if desired.
 
+Note that C<use Test::Warnings 'warnings'> will give you a C<warnings>
+subroutine in your namespace (most likely C<main>, if you're writing a test),
+so you (or things you load) can't subsequently do C<< warnings->import >> --
+it will result in the error: "Not enough arguments for
+Test::Warnings::warnings at ..., near "warnings->import"".  To work around
+this, either use the fully-qualified form (C<Test::warnings>) or make your
+calls to the C<warnings> package first.
+
 =head2 C<< warning( { code } ) >>
 
 Same as C<< warnings( { code } ) >>, except a scalar is always returned - the
@@ -304,15 +314,15 @@ So instead, change your test to:
 
 =head1 IMPORT OPTIONS
 
-=over 4
+=head2 C<:all>
 
-=item * C<:all> - Imports all functions listed above
+Imports all functions listed above
 
-=item * C<:no_end_test> - Disables the addition of a C<had_no_warnings> test
+=head2 C<:no_end_test>
+
+Disables the addition of a C<had_no_warnings> test
 via C<END> or C<done_testing>
 
-=back
-
 =head1 CAVEATS
 
 =for stopwords smartmatch TODO irc
@@ -369,13 +379,6 @@ environment
 
 =back
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Warnings>.
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =for stopwords YANWT
@@ -410,35 +413,34 @@ L<Test::Fatal>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Warnings>
+(or L<bug-Test-Warnings@rt.cpan.org|mailto:bug-Test-Warnings@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/perl-qa.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<irc://irc.perl.org/#perl-qa>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTOR
+
+=for stopwords A. Sinan Unur
+
+A. Sinan Unur <nanis@cpan.org>
+
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 CONTRIBUTORS
-
-=for stopwords A. Sinan Unur Graham Knop Leon Timmermans
-
-=over 4
-
-=item *
-
-A. Sinan Unur <nanis@cpan.org>
-
-=item *
-
-Graham Knop <haarg@haarg.org>
-
-=item *
-
-Leon Timmermans <fawaka@gmail.com>
-
-=back
-
 =cut
